'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.unauthorized = unauthorized;

var _constants = require('../constants');

var _constants2 = _interopRequireDefault(_constants);

var _logger = require('../logger');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var unauthorizedRequest = function unauthorizedRequest() {
  return {
    type: _constants2.default.UNAUTHORIZED_REQUEST
  };
};

var showGlobalError = function showGlobalError() {
  return {
    type: _constants2.default.GLOBAL_ERROR
  };
};

function unauthorized(dispatch, action, queued) {
  console.log('unauthorized queued action', queued);
  return function (resp) {
    console.log('resp from ci-core/unauthorized', resp);
    if (resp && !resp.url && !resp.method && !resp.response && !resp.status && !resp.timeout) {
      dispatch(showGlobalError());
      (0, _logger.logMessage)(resp);
    }

    var r = resp.response || {};
    var err = {
      status: resp.status || r.status,
      error: r.error,
      body: r.body,
      text: r.text
    };

    if (resp.response && resp.response.status === 401) {
      (0, _logger.logMessage)('Error 401 - unauthorized - for ' + url);
      return dispatch(unauthorizedRequest());
    }

    if (resp && resp.response && resp.response.status > 401) {
      (0, _logger.logMessage)('Error ' + resp.response.status + ' - for ' + url);
      logException(resp);
    }

    if (resp.status && resp.status.toString() === '202' || resp.response && resp.response.status.toString() === '202') {
      (0, _logger.logMessage)('got a 202 for ' + resp.url + ' with method ' + resp.method);
      if (queued) {
        queued(resp);
      } else {
        //safe fallback to default 202 page.
        //TODO: probably in config
        window.location = '/202';
      }
    }

    // return null;
    return dispatch(action(err));
  };
}

exports.default = {
  unauthorized: unauthorized
};