'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getEntityIcon = getEntityIcon;
exports.getEntityNameAndIcon = getEntityNameAndIcon;
var layoutsConfig = __cluedIn.layouts;
var entitiesConfig = __cluedIn.widgetConfiguration;

var defaultEntityConfig = {
  entityType: 'default',
  isDefault: true,
  includeSuggestedSearches: true,
  placeSuggestedSearches: 'main',
  suggestedSearchFilter: [],
  layout: {
    name: 'Standard'
  },
  widgets: [{ name: 'EntityHeader', place: 'header' }, { name: 'EntityProperty', place: 'main' /*, size: '8'*/ }, { name: 'EntitySourceAndProfile', place: 'main' }]
};

var defaultLayoutConfig = {
  code: 'Standard',
  isDefault: true,
  children: [{
    type: 'row',
    columns: [{
      size: 12,
      name: 'header'
    }]
  }, {
    type: 'grid',
    size: 4,
    name: 'main'
  }]
};

var getAllWidgetConfiguration = exports.getAllWidgetConfiguration = function getAllWidgetConfiguration() {
  return entitiesConfig;
};

var getEntityConfiguration = exports.getEntityConfiguration = function getEntityConfiguration(entityType) {
  return entitiesConfig.find(entitiesConfig, function (entityConfig) {
    return entityConfig.entityType.toLowerCase() === entityType.toLowerCase();
  });
};

var getEntityNameFromConfiguration = exports.getEntityNameFromConfiguration = function getEntityNameFromConfiguration(entityType) {
  var configForEntity = getEntityConfiguration(entityType);

  return configForEntity ? configForEntity.displayName : entityType;
};

function getEntityIcon(entityType) {
  var configForEntity = getEntityConfiguration(entityType);

  return configForEntity ? configForEntity.icon : entityType;
}

function getEntityNameAndIcon(entityType) {
  var configForEntity = getEntityConfiguration(entityType);

  if (configForEntity) {
    return {
      icon: configForEntity.icon,
      name: configForEntity.displayName
    };
  }

  return {
    icon: void 0,
    name: configForEntity.displayName
  };
}

var getWidgetConfiguration = exports.getWidgetConfiguration = function getWidgetConfiguration(entityType, org) {
  var widgetConfigForOrg = entitiesConfig.find(function (entityConfig) {
    return entityConfig.entityType.toLowerCase() === entityType.toLowerCase() && entityConfig.owner === org;
  });

  if (!widgetConfigForOrg) {
    widgetConfigForOrg = entitiesConfig.find(function (entityConfig) {
      return entityConfig.entityType.toLowerCase() === entityType.toLowerCase();
    });
  }

  return widgetConfigForOrg && widgetConfigForOrg.widgets && widgetConfigForOrg.widgets.length > 0 ? widgetConfigForOrg : defaultEntityConfig;
};

var getLayout = exports.getLayout = function getLayout(layoutCode) {
  var layoutConfig = entitiesConfig.find(layoutsConfig, function (layoutConfig) {
    return layoutConfig.code === layoutCode;
  });

  return layoutConfig ? layoutConfig : defaultLayoutConfig;
};

var getEntityLink = exports.getEntityLink = function getEntityLink(id, entityType) {
  var defaultEntity = 'entity/' + id;
  var entityConfig = getWidgetConfiguration(entityType);

  if (entityConfig && entityConfig.route) {
    var entityUrl = entityConfig.route.replace(':id', id);

    return '/' + entityUrl;
  }
  return '/' + defaultEntity;
};