'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.teamDomain = exports.url = exports.getCurrentToken = exports.isProduction = exports.env = exports.clientId = undefined;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _jsCookie = require('js-cookie');

var _jsCookie2 = _interopRequireDefault(_jsCookie);

var _subdomain = require('../helpers/subdomain');

var _global = require('./global');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var runtimeConfigurationStr = (0, _global.getCluedInGlobal)('runtimeConfiguration');
var teamDomainStr = (0, _global.getCluedInGlobal)('teamDomain');

var runtimeConfiguration = void 0;

try {
  runtimeConfiguration = JSON.parse(runtimeConfigurationStr || '');
} catch (err) {
  console.error('JSON.parse(runtimeConfigurationStr) failed from cluedin-core');
  runtimeConfiguration = {};
}

if (!runtimeConfiguration) {
  console.error('runtimeConfiguration is empty');
}

var teamDomainValue = void 0;

if ((0, _subdomain.getSubdomain)() !== 'app') {
  try {
    teamDomainValue = JSON.parse(teamDomainStr || '');
  } catch (e) {
    console.error('invalid team domain', e);
    teamDomainValue = null;
  }
}

var clientId = exports.clientId = teamDomainValue ? teamDomainValue.clientId : '';

if ((0, _subdomain.getSubdomain)() !== 'app' && !clientId) {
  throw new Error('Invalid clientId - check teamDomain');
}

if (!runtimeConfiguration.app || !runtimeConfiguration.authApi || !runtimeConfiguration.bucket || !runtimeConfiguration.cookieDomainName || !runtimeConfiguration.env || !runtimeConfiguration.mainDomain || !runtimeConfiguration.protocol || !runtimeConfiguration.publicApi || !runtimeConfiguration.webApi) {
  console.error('invalid runtime configuration');
  console.error(runtimeConfiguration);
}

var cluedinConfiguration = (0, _extends3.default)({}, runtimeConfiguration, {
  website: 'https://www.cluedin.net',
  graphQL: runtimeConfiguration.webApi + 'api/graphql',
  api: '' + runtimeConfiguration.webApi,
  auth: '' + runtimeConfiguration.authApi,
  mainApp: runtimeConfiguration.app,
  app: '' + runtimeConfiguration.protocol + clientId + '.' + runtimeConfiguration.mainDomain + '/',
  cdnUrl: '' + runtimeConfiguration.bucket,
  mainCookieDomain: '' + runtimeConfiguration.cookieDomainName
});

var env = exports.env = runtimeConfiguration.env;

var isProduction = exports.isProduction = env === 'production';

var getCurrentToken = exports.getCurrentToken = function getCurrentToken() {
  var tokenForAllInString = _jsCookie2.default.get('token');
  var tokenParsed = void 0;

  try {
    if (tokenForAllInString) {
      tokenParsed = JSON.parse(tokenForAllInString);
    } else {
      tokenParsed = '';
    }
  } catch (e) {
    console.error('Cookie parsing from cluedin-core does not work. Check value of cookie');
  }

  if (!tokenParsed) {
    return null;
  }
  if (tokenParsed.length === 0) {
    return null;
  }

  var tokenByClientId = tokenParsed.find(function (token) {
    return token.clientId.toLowerCase() === clientId.toLowerCase();
  });

  if (!tokenByClientId) {
    return null;
  }

  return tokenByClientId.token;
};

var url = exports.url = cluedinConfiguration;
var teamDomain = exports.teamDomain = teamDomainValue;

exports.default = {
  clientId: clientId,
  url: url,
  env: env,
  teamDomain: teamDomain,
  getCurrentToken: getCurrentToken,
  getCluedInGlobal: _global.getCluedInGlobal
};