'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.rawRequest = exports.appFrontApiRequest = exports.frontApiRequest = exports.apiRequest = exports.authRequest = exports.authWithoutCreds = undefined;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _fromServer = require('../fromServer');

var _superagent = require('superagent');

var _superagent2 = _interopRequireDefault(_superagent);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

if (_fromServer.env === 'mock') {
  require('./mock')(_superagent2.default);
}

var agent = require('superagent-promise')(_superagent2.default, _promise2.default);

var defaultHeaders = {};
var responseHeaders = {};
var defaultTimeout = {
  response: 60e3 * 60, // Wait 1hour for the server to start sending,
  deadline: 60e3 * 60 * 24 // and allow 24 hours sec for the file to finish loading.

};

var getDefaultHeaders = function getDefaultHeaders() {
  return {
    Authorization: 'Bearer ' + (0, _fromServer.getCurrentToken)(),
    'Accept': 'application/json, text/plain, */*'
  };
};

function isObject(obj) {
  return Object(obj) === obj;
}

var authWithoutCreds = exports.authWithoutCreds = function authWithoutCreds(method, url) {
  url = _fromServer.url.auth + url;

  return agent(method, url).timeout(defaultTimeout);
};

var authRequest = exports.authRequest = function authRequest(method, url, data) {
  url = _fromServer.url.auth + url;

  var r = agent(method, url).timeout(defaultTimeout).set(getDefaultHeaders());

  if (data) {
    r.send(data);
  }

  return r;
};

var getCachingHeaders = function getCachingHeaders(url) {
  var headers = {};
  var lastHeaders = responseHeaders[url];
  if (!lastHeaders) return headers;
  if (lastHeaders['last-modified']) headers['If-Modified-Since'] = lastHeaders['last-modified'];
  if (lastHeaders['etag']) headers['If-None-Match'] = lastHeaders['etag'];
  return headers;
};

var apiRequest = exports.apiRequest = function apiRequest(method, url, data, type) {
  console.log('url in apiREquest from core');
  url = _fromServer.url.api + url;

  var r = agent(method, url).timeout(defaultTimeout).set(getDefaultHeaders());
  r.set(getCachingHeaders(url));

  if (data) {
    r.send(data);
  }

  return r.then(function (resp) {
    if (resp) {
      // spacial "error" case for 202 queued // this should only be tmp
      if (resp.status.toString() === '202') {
        throw resp;
      }
      resp.__token = (0, _fromServer.getCurrentToken)();
      responseHeaders[url] = (0, _extends3.default)({}, resp.headers);
    }

    return resp;
  });
};

var setHeaders = function setHeaders(field, value) {
  if (isObject(field)) {
    for (var key in field) {
      this.set(key, field[key]);
    }

    return this;
  }

  defaultHeaders[field] = value;

  return this;
};

var frontApiRequest = exports.frontApiRequest = function frontApiRequest(method, url, data, type) {
  url = _fromServer.url.app + url;

  var agentCall = agent(method, url).timeout(defaultTimeout);

  if (data) {
    agentCall = agentCall.send(data);
  }

  return agentCall.withCredentials().set(getDefaultHeaders());
};

var appFrontApiRequest = exports.appFrontApiRequest = function appFrontApiRequest(method, url, data, type) {
  url = _fromServer.url.mainApp + url;

  var agentCall = agent(method, url).timeout(defaultTimeout);

  if (data) {
    agentCall = agentCall.send(data);
  }

  return agentCall.withCredentials().set(getDefaultHeaders());
};

var rawRequest = exports.rawRequest = function rawRequest(method, url) {
  return agent(method, url).timeout(defaultTimeout).set(getDefaultHeaders()).then(function (resp) {
    if (resp) {
      resp.__token = (0, _fromServer.getCurrentToken)();
    }

    return resp;
  });
};

authRequest.set = setHeaders;
apiRequest.set = setHeaders;

exports.default = {
  authRequest: authRequest,
  apiRequest: apiRequest,
  frontApiRequest: frontApiRequest,
  rawRequest: rawRequest,
  appFrontApiRequest: appFrontApiRequest
};